hideInputMethod method
- @SupportedPlatforms.new(platforms: [AndroidPlatform(apiName: 'InputMethodManager.hideSoftInputFromWindow', apiUrl: 'https://developer.android.com/reference/android/view/inputmethod/InputMethodManager#hideSoftInputFromWindow(android.os.IBinder,%20int)'), IOSPlatform(apiName: 'UIView.endEditing', apiUrl: 'https://developer.apple.com/documentation/uikit/uiview/1619630-endediting')])
inherited
Request to hide the soft input view from the context of the view that is currently accepting input.
Implementation
@SupportedPlatforms(
platforms: [
AndroidPlatform(
apiName: 'InputMethodManager.hideSoftInputFromWindow',
apiUrl:
'https://developer.android.com/reference/android/view/inputmethod/InputMethodManager#hideSoftInputFromWindow(android.os.IBinder,%20int)',
),
IOSPlatform(
apiName: 'UIView.endEditing',
apiUrl:
'https://developer.apple.com/documentation/uikit/uiview/1619630-endediting',
),
],
)
Future<void> hideInputMethod() {
throw UnimplementedError(
'${PlatformInAppWebViewControllerMethod.hideInputMethod.name} is not implemented on the current platform',
);
}